pub struct RangeOnCurve { /* private fields */ }
The range on which a curve should be approximated

Implementations

Construct an instance of RangeOnCurve

Ranges are normalized on construction, meaning that the order of vertices passed to this constructor does not influence the range that is constructed.

This is done to prevent bugs during mesh construction: The curve approximation code is regularly faced with ranges that are reversed versions of each other. This can lead to slightly different approximations, which in turn leads to the aforementioned invalid meshes.

The caller can use is_reversed to determine, if the range was reversed during normalization, to adjust the approximation accordingly.

Indicate whether the range was reversed during normalization

Access the start of the range

Access the end of the range

Compute the signed length of the range

Compute the absolute length of the range

Compute the direction of the range

Returns a Scalar that is zero or +/- one.