pub trait Sweep { type Swept; fn sweep(self, path: impl Into<Vector<3>>) -> Self::Swept; }
Sweep an object along a path to create another object
The object that is created by sweeping the implementing object
Sweep the object along the given path