pub trait SurfaceVertexBuilder {
    fn infer_global_position(&mut self) -> Point<3>;
}
Builder API for PartialSurfaceVertex

Required Methods

Infer the position of the surface vertex’ global form

Updates the global vertex referenced by this surface vertex with the inferred position, and also returns the position.

Implementors