Objects of a shape

Objects, in Fornjot parlance, are the elements that make up shapes. An object can be simple and just contain data (like GlobalVertex, for example), or they can be quite complex and refer to other objects.

Structs

A curve, defined in local surface coordinates

A cycle of connected half-edges

A face of a shape

A collection of faces

A curve, defined in global (3D) coordinates

An edge, defined in global (3D) coordinates

A vertex, defined in global (3D) coordinates

A half-edge

A 3-dimensional closed shell

A 2-dimensional shape

A 3-dimensional shape

A vertex, defined in surface (2D) coordinates

A surface that was swept from a curve

A vertex

Enums

A one-dimensional shape

The handedness of a face’s coordinate system

A two-dimensional shape