Insert

Trait Insert 

pub trait Insert: Sized {
    type Inserted;

    // Required method
    fn insert(self, services: &mut Services) -> Self::Inserted;
}
Insert an object into its respective store

This is the only primitive operation that is directly understood by Service<Objects>. All other operations are built on top of it.

Required Associated Types

type Inserted

The type of Self, once it has been inserted

Usually this is just Handle<Self>, but there are some more complex cases where this type needs to be customized.

Required Methods

fn insert(self, services: &mut Services) -> Self::Inserted

Insert the object into its respective store

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors