Struct fj_kernel::algorithms::approx::curve::RangeOnCurve
source · [−]pub struct RangeOnCurve { /* private fields */ }Expand description
The range on which a curve should be approximated
Implementations
sourceimpl RangeOnCurve
impl RangeOnCurve
sourcepub fn new([a, b]: [Vertex; 2]) -> Self
pub fn new([a, b]: [Vertex; 2]) -> Self
Construct an instance of RangeOnCurve
Ranges are normalized on construction, meaning that the order of vertices passed to this constructor does not influence the range that is constructed.
This is done to prevent bugs during mesh construction: The curve approximation code is regularly faced with ranges that are reversed versions of each other. This can lead to slightly different approximations, which in turn leads to the aforementioned invalid meshes.
The caller can use is_reversed to determine, if the range was reversed
during normalization, to adjust the approximation accordingly.
sourcepub fn is_reversed(&self) -> bool
pub fn is_reversed(&self) -> bool
Indicate whether the range was reversed during normalization
sourcepub fn signed_length(&self) -> Scalar
pub fn signed_length(&self) -> Scalar
Compute the signed length of the range